==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/47/4791e4d1e004a43d274eab49a1f332ac.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Event/EmailValidationEvent.php */
class __TwigTemplate_c1d9965e2f6325f0369bb990dd37c8d5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Event;

use Symfony\\Contracts\\EventDispatcher\\Event;

class EmailValidationEvent extends Event
{
    /**
     * @var bool
     */
    protected \$isValid = true;

    /**
     * @var string|null
     */
    protected \$invalidReason;

    /**
     * @param string \$address
     */
    public function __construct(
        protected \$address
    ) {
    }

    /**
     * @return string
     */
    public function getAddress()
    {
        return \$this->address;
    }

    public function setInvalid(\$reason): void
    {
        \$this->isValid       = false;
        \$this->invalidReason = \$reason;

        \$this->stopPropagation();
    }

    /**
     * @return bool
     */
    public function isValid()
    {
        return \$this->isValid;
    }

    /**
     * @return string|null
     */
    public function getInvalidReason()
    {
        return \$this->invalidReason;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Event/EmailValidationEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Event/EmailValidationEvent.php", "/var/www/mautic-ktn/app/bundles/EmailBundle/Event/EmailValidationEvent.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/47/4791e4d1e004a43d274eab49a1f332ac.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Event/EmailValidationEvent.php */
class __TwigTemplate_c1d9965e2f6325f0369bb990dd37c8d5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Event;

use Symfony\\Contracts\\EventDispatcher\\Event;

class EmailValidationEvent extends Event
{
    /**
     * @var bool
     */
    protected \$isValid = true;

    /**
     * @var string|null
     */
    protected \$invalidReason;

    /**
     * @param string \$address
     */
    public function __construct(
        protected \$address
    ) {
    }

    /**
     * @return string
     */
    public function getAddress()
    {
        return \$this->address;
    }

    public function setInvalid(\$reason): void
    {
        \$this->isValid       = false;
        \$this->invalidReason = \$reason;

        \$this->stopPropagation();
    }

    /**
     * @return bool
     */
    public function isValid()
    {
        return \$this->isValid;
    }

    /**
     * @return string|null
     */
    public function getInvalidReason()
    {
        return \$this->invalidReason;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Event/EmailValidationEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Event/EmailValidationEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Event/EmailValidationEvent.php");
    }
}
